@@ -1,16 +1,21 @@
-use 5.008;    #utf8
+use 5.006;    # our
 use strict;
 use warnings;
-use utf8;
 
 package Dist::Zilla::Plugin::Test::Compile::PerFile;
 
-our $VERSION = '0.003000';
+our $VERSION = '0.004000';
 
 # ABSTRACT: Create a single .t for each compilable file in a distribution
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
+use B ();
+
+BEGIN {
+  ## no critic (ProhibitCallsToUnexportedSubs)
+  *_HAVE_PERLSTRING = defined &B::perlstring ? sub() { 1 } : sub() { 0 };
+}
 use Moose qw( with around has );
 use MooseX::LazyRequire;
 
@@ -19,7 +24,6 @@ with 'Dist::Zilla::Role::FileGatherer', 'Dist::Zilla::Role::TextTemplate';
 use Path::Tiny qw(path);
 use File::ShareDir qw(dist_dir);
 use Moose::Util::TypeConstraints qw(enum);
-use Dist::Zilla::Util::ConfigDumper qw( config_dumper );
 
 ## no critic (ProhibitPackageVars)
 our %path_translators;
@@ -82,11 +86,24 @@ around mvp_aliases => sub {
   return $hash;
 };
 
-around dump_config => config_dumper( __PACKAGE__,
-  { attrs => ['finder'] },
-  qw( xt_mode prefix file skip path_translator test_template ),
-  sub { $_[1]->{file} = [ sort @{ $_[0]->file } ] },
-);
+around dump_config => sub {
+  my ( $orig, $self, @args ) = @_;
+  my $config = $self->$orig(@args);
+  my $localconf = $config->{ +__PACKAGE__ } = {};
+
+  $localconf->{finder}          = $self->finder if $self->has_finder;
+  $localconf->{xt_mode}         = $self->xt_mode;
+  $localconf->{prefix}          = $self->prefix;
+  $localconf->{file}            = [ sort @{ $self->file } ];
+  $localconf->{skip}            = $self->skip;
+  $localconf->{path_translator} = $self->path_translator;
+  $localconf->{test_template}   = $self->test_template;
+
+  $localconf->{ q[$] . __PACKAGE__ . '::VERSION' } = $VERSION
+    unless __PACKAGE__ eq ref $self;
+
+  return $config;
+};
 
 
 
@@ -266,6 +283,11 @@ has path_translator => ( is => ro =>, isa => enum( [ sort keys %path_translators
 
 
 
+
+
+
+
+
 
 
 
@@ -274,17 +296,34 @@ has path_translator => ( is => ro =>, isa => enum( [ sort keys %path_translators
 
 has test_template => ( is => ro =>, isa => enum( [ sort keys %templates ] ), lazy_build => 1 );
 
+sub _quoted {
+  no warnings 'numeric';
+  ## no critic (ProhibitBitwiseOperators,ProhibitCallsToUndeclaredSubs)
+  ## no critic (ProhibitCallsToUnexportedSubs,ProhibitUnusedVarsStricter)
+  !defined $_[0]
+    ? 'undef()'
+    : ( length( ( my $dummy = q[] ) & $_[0] ) && 0 + $_[0] eq $_[0] && $_[0] * 0 == 0 ) ? $_[0]    # numeric detection
+    : _HAVE_PERLSTRING ? B::perlstring( $_[0] )
+    :                    qq["\Q$_[0]\E"];
+}
+
 sub _generate_file {
   my ( $self, $name, $file ) = @_;
+  my $relpath = ( $file =~ /\Alib\/(.*)\z/msx ? $1 : q[./] . $file );
+
+  $self->log_debug("relpath for $file is: $relpath");
+
   my $code = sub {
     return $self->fill_in_string(
       $self->_test_template_content,
       {
         file              => $file,
+        relpath           => $relpath,
         plugin_module     => $self->meta->name,
         plugin_name       => $self->plugin_name,
         plugin_version    => ( $self->VERSION ? $self->VERSION : '<self>' ),
         test_more_version => '0.89',
+        quoted            => \&_quoted,
       },
     );
   };
@@ -339,6 +378,10 @@ has _test_template         => ( is => ro =>, isa => Defined =>, lazy_build => 1,
 has _test_template_content => ( is => ro =>, isa => Defined =>, lazy_build => 1, init_arg => undef );
 has _finder_objects => ( is => ro =>, isa => 'ArrayRef', lazy_build => 1, init_arg => undef );
 
+__PACKAGE__->meta->make_immutable;
+no Moose;
+no Moose::Util::TypeConstraints;
+
 sub _build_xt_mode {
   return;
 }
@@ -444,9 +487,6 @@ sub _found_files {
   return [ values %by_name ];
 }
 
-__PACKAGE__->meta->make_immutable;
-no Moose;
-no Moose::Util::TypeConstraints;
 
 1;
 
@@ -462,7 +502,7 @@ Dist::Zilla::Plugin::Test::Compile::PerFile - Create a single .t for each compil
 
 =head1 VERSION
 
-version 0.003000
+version 0.004000
 
 =head1 SYNOPSIS
 
@@ -706,6 +746,11 @@ Provided Templates:
 A very basic standard template, which C<use>'s C<Test::More>, does a C<requires_ok($file)> for the requested file, and nothing
 else.
 
+=item * C<02-raw-require.t.tpl>
+
+A minimalist spartan C<require_ok> implementation, but without using C<Test::More>. Subsequently faster under Test2 and can expose
+more issues where modules have implicit C<use>
+
 =back
 
 =for Pod::Coverage BUILD
@@ -782,7 +827,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2017 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
